Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(219)

Unified Diff: courgette/disassembler.h

Issue 2793153003: [Courgette] Refactor: Store Label Annotation in AssemblyProgram for patch generation. (Closed)
Patch Set: Rename *_label_annotation to *_label_annotations. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « courgette/courgette_tool.cc ('k') | courgette/disassembler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: courgette/disassembler.h
diff --git a/courgette/disassembler.h b/courgette/disassembler.h
index 379a75aa376a745fb0521a7a264145643fac09e2..d3175d42c8b148c3beec93b5820207d93007965c 100644
--- a/courgette/disassembler.h
+++ b/courgette/disassembler.h
@@ -91,9 +91,9 @@ class Disassembler : public AddressTranslator {
virtual bool ParseHeader() = 0;
// Extracts and stores references from the main image. Returns a new
- // AssemblyProgram initialized using data parsed from the main image, or null
- // on failure.
- std::unique_ptr<AssemblyProgram> Disassemble();
+ // AssemblyProgram initialized using data parsed from the main image and
+ // |annotate_labels|, or null on failure.
+ std::unique_ptr<AssemblyProgram> Disassemble(bool annotate_labels);
// ok() may always be called but returns true only after ParseHeader()
// succeeds.
« no previous file with comments | « courgette/courgette_tool.cc ('k') | courgette/disassembler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698